@@ -116,7 +116,7 @@ def paasta_remote_run_copy(
     )
     if poll_response.status != 200:
         print(
-            f"Unable to find running remote-run pod: have you started one with `paasta remote-run start`?"
+            "Unable to find running remote-run pod: have you started one with `paasta remote-run start`?"
         )
         return 1
 
@@ -256,7 +256,7 @@ def paasta_remote_run_start(
                 namespace=poll_response.namespace,
                 pod=poll_response.pod_name,
                 source=filename,
-                dest=os.path.join("/tmp", filename),
+                dest=os.path.join("/tmp", os.path.basename(filename)),
                 token=token_response.token,
             ).split(" ")
             call = subprocess.run(cp_command, capture_output=True)
@@ -369,7 +369,7 @@ def add_subparser(subparsers: argparse._SubParsersAction) -> None:
             "automatically stopped (capped by the API backend)"
         ),
         type=int,
-        default=1800,
+        default=7200,
     )
     start_parser.add_argument(
         "-f",
