@@ -1,4 +1,6 @@
 import asyncio
+import logging
+from asyncio.tasks import Task
 from collections import defaultdict
 from enum import Enum
 from typing import Any
@@ -16,6 +18,7 @@ from typing import Union
 
 import a_sync
 import pytz
+import requests.exceptions
 from kubernetes.client import V1Container
 from kubernetes.client import V1ControllerRevision
 from kubernetes.client import V1Pod
@@ -74,6 +77,8 @@ INSTANCE_TYPE_CR_ID = dict(
     monkrelaycluster=monkrelaycluster_tools.cr_id,
 )
 
+logger = logging.getLogger(__name__)
+
 
 class ServiceMesh(Enum):
     SMARTSTACK = "smartstack"
@@ -99,6 +104,7 @@ class KubernetesVersionDict(TypedDict, total=False):
     config_sha: str
     pods: Sequence[Mapping[str, Any]]
     namespace: str
+    container_port: Optional[int]
 
 
 def cr_id(service: str, instance: str, instance_type: str) -> Mapping[str, str]:
@@ -346,31 +352,49 @@ async def mesh_status(
 
     pods = await pods_task
     for location, hosts in node_hostname_by_location.items():
-        host = replication_checker.get_hostname_in_pool(hosts, instance_pool)
-        if service_mesh == ServiceMesh.SMARTSTACK:
-            mesh_status["locations"].append(
-                _build_smartstack_location_dict(
-                    synapse_host=host,
-                    synapse_port=settings.system_paasta_config.get_synapse_port(),
-                    synapse_haproxy_url_format=settings.system_paasta_config.get_synapse_haproxy_url_format(),
-                    registration=registration,
-                    pods=pods,
-                    location=location,
-                    should_return_individual_backends=should_return_individual_backends,
-                )
-            )
-        elif service_mesh == ServiceMesh.ENVOY:
-            mesh_status["locations"].append(
-                _build_envoy_location_dict(
-                    envoy_host=host,
-                    envoy_admin_port=settings.system_paasta_config.get_envoy_admin_port(),
-                    envoy_admin_endpoint_format=settings.system_paasta_config.get_envoy_admin_endpoint_format(),
-                    registration=registration,
-                    pods=pods,
-                    location=location,
-                    should_return_individual_backends=should_return_individual_backends,
-                )
-            )
+        max_retries = 3
+
+        for attempt in range(max_retries):
+            host = replication_checker.get_hostname_in_pool(hosts, instance_pool)
+            try:
+                if service_mesh == ServiceMesh.SMARTSTACK:
+                    location_dict = _build_smartstack_location_dict(
+                        synapse_host=host,
+                        synapse_port=settings.system_paasta_config.get_synapse_port(),
+                        synapse_haproxy_url_format=settings.system_paasta_config.get_synapse_haproxy_url_format(),
+                        registration=registration,
+                        pods=pods,
+                        location=location,
+                        should_return_individual_backends=should_return_individual_backends,
+                    )
+                elif service_mesh == ServiceMesh.ENVOY:
+                    location_dict = _build_envoy_location_dict(
+                        envoy_host=host,
+                        envoy_admin_port=settings.system_paasta_config.get_envoy_admin_port(),
+                        envoy_admin_endpoint_format=settings.system_paasta_config.get_envoy_admin_endpoint_format(),
+                        registration=registration,
+                        pods=pods,
+                        location=location,
+                        should_return_individual_backends=should_return_individual_backends,
+                    )
+
+                mesh_status["locations"].append(location_dict)
+                return mesh_status
+
+            except requests.exceptions.ConnectTimeout:
+                if attempt < max_retries - 1:
+                    logger.warning(
+                        "attempt %s/%s: Unable to connect to %s, retrying (on another host, hopefully)...",
+                        attempt,
+                        max_retries,
+                        host,
+                    )
+                    continue
+                else:
+                    logger.critical(
+                        "Unable to connect to %s, not retrying again.", host
+                    )
+                    raise
     return mesh_status
 
 
@@ -697,6 +721,7 @@ async def kubernetes_status_v2(
                 instance=instance,
                 namespaces=relevant_namespaces,
                 pod_status_by_sha_and_readiness_task=pod_status_by_sha_and_readiness_task,  # type: ignore  # PAASTA-18698; ignoring due to unexpected type mismatch
+                container_port=job_config.get_container_port(),
             )
         )
         tasks.extend([pod_status_by_sha_and_readiness_task, versions_task])  # type: ignore  # PAASTA-18698; ignoring due to unexpected type mismatch
@@ -716,6 +741,7 @@ async def kubernetes_status_v2(
                 instance=instance,
                 namespaces=relevant_namespaces,
                 pod_status_by_replicaset_task=pod_status_by_replicaset_task,  # type: ignore  # PAASTA-18698; ignoring due to unexpected type mismatch
+                container_port=job_config.get_container_port(),
             )
         )
         tasks.extend([pod_status_by_replicaset_task, versions_task])  # type: ignore  # PAASTA-18698; ignoring due to unexpected type mismatch
@@ -787,6 +813,7 @@ async def get_versions_for_replicasets(
     instance: str,
     namespaces: Iterable[str],
     pod_status_by_replicaset_task: "asyncio.Future[Mapping[str, Sequence[asyncio.Future[Dict[str, Any]]]]]",
+    container_port: Optional[int],
 ) -> List[KubernetesVersionDict]:
 
     replicaset_list: List[V1ReplicaSet] = []
@@ -814,6 +841,7 @@ async def get_versions_for_replicasets(
                 replicaset,
                 kube_client,
                 pod_status_by_replicaset.get(replicaset.metadata.name),
+                container_port,
             )
             for replicaset in actually_running_replicasets
         ]
@@ -825,6 +853,7 @@ async def get_replicaset_status(
     replicaset: V1ReplicaSet,
     client: kubernetes_tools.KubeClient,
     pod_status_tasks: Sequence["asyncio.Future[Dict[str, Any]]"],
+    container_port: Optional[int],
 ) -> KubernetesVersionDict:
     return {
         "name": replicaset.metadata.name,
@@ -839,6 +868,7 @@ async def get_replicaset_status(
         "config_sha": replicaset.metadata.labels.get("paasta.yelp.com/config_sha"),
         "pods": await asyncio.gather(*pod_status_tasks) if pod_status_tasks else [],
         "namespace": replicaset.metadata.namespace,
+        "container_port": container_port,
     }
 
 
@@ -1062,6 +1092,7 @@ async def get_versions_for_controller_revisions(
     instance: str,
     namespaces: Iterable[str],
     pod_status_by_sha_and_readiness_task: "asyncio.Future[Mapping[Tuple[str, str], Mapping[bool, Sequence[asyncio.Future[Mapping[str, Any]]]]]]",
+    container_port: Optional[int] = None,
 ) -> List[KubernetesVersionDict]:
     controller_revision_list: List[V1ControllerRevision] = []
 
@@ -1091,6 +1122,7 @@ async def get_versions_for_controller_revisions(
                 cr,
                 kube_client,
                 pod_status_by_sha_and_readiness[(git_sha, config_sha)],
+                container_port=container_port,
             )
             for (git_sha, config_sha), cr in cr_by_shas.items()
         ]
@@ -1105,6 +1137,7 @@ async def get_version_for_controller_revision(
     pod_status_tasks_by_readiness: Mapping[
         bool, Sequence["asyncio.Future[Mapping[str, Any]]"]
     ],
+    container_port: Optional[int] = None,
 ) -> KubernetesVersionDict:
     all_pod_status_tasks = [
         task for tasks in pod_status_tasks_by_readiness.values() for task in tasks
@@ -1121,6 +1154,7 @@ async def get_version_for_controller_revision(
         "config_sha": cr.metadata.labels.get("paasta.yelp.com/config_sha"),
         "pods": [task.result() for task in all_pod_status_tasks],
         "namespace": cr.metadata.namespace,
+        "container_port": container_port,
     }
 
 
@@ -1156,7 +1190,7 @@ async def kubernetes_status(
 
     # this task is necessary for mesh_status, but most other use cases want
     # just the list of pods
-    pods_task = asyncio.create_task(
+    pods_task: Task[Sequence[V1Pod]] = asyncio.create_task(
         kubernetes_tools.pods_for_service_instance(
             service=job_config.service,
             instance=job_config.instance,
